#!/usr/bin/python
# -*- coding: utf-8 -*-

# options.py
#
# This file is part of BotMU
#
# Author: Raphaël Perraudeau <r.perraudeau@gmail.com>
# Copyright: 2011 Raphaël Perraudeau <r.perraudeau@gmail.com>
# Licence: GNU/GPL
#
# Home page: <http://botmu.sourceforge.net/>


# Inclusions des modules générique
# Native
import os
import platform

# Pyqt4
from PyQt4.QtCore import *
from PyQt4.QtGui import *



#############################################################################
class Options(QDialog):
 
	#========================================================================
	def __init__(self, parent=None):
		super(Options,self).__init__(parent)
		self.parent = parent
		self.defaultDir = self.parent.defaultDir
		self.userPersonalPath = self.parent.userPersonalPath
		
 		self.setGeometry(150, 150, 500, 200)
		self.setMinimumSize(500, 200)
		self.setMaximumSize(500, 200)
		self.setWindowTitle(u"Préférences")
		
		#Mise à jour auto:
		self.labelCheckupdate = QLabel(u"Mise à jour auto:", self)
		self.checkupdate = QCheckBox()
		self.checkupdateDelay = QComboBox()
		self.checkupdateDelay.addItem("Quotidien", 0)
		self.checkupdateDelay.addItem("Hebdomadaire", 1)
		self.checkupdateDelay.addItem("Mensuel", 2)
		
		if(self.parent.checkUpdate==1):
			self.checkupdate.setCheckState(Qt.Checked)
		#
		self.labelfichier = QLabel(u"Emplacement par default:", self)
		self.fichier = QLineEdit(u"%s" % self.defaultDir, self)
		self.fichierSelect = QPushButton(u"Parcourir", self)
		
		self.labellimit = QLabel(u"Limite de debit:", self)
		self.limit = QLineEdit(u"%s" % self.parent.limit, self)
		self.labellimit2 = QLabel(u"Ko/s (0 pour illimité)", self)
		
		self.save = QPushButton(QIcon('icons/start.png'), u"  Enregistrer", self)
		self.cancel = QPushButton(QIcon('icons/stop.png'), u"  Annuler", self)
		
		
		self.fichierSelect.clicked.connect(self.selectDir_m)
		self.save.clicked.connect(self.save_m)
		self.cancel.clicked.connect(self.cancel_m)
		
		
		posit = QGridLayout()
		
		posit.addWidget(self.labelfichier, 1, 0)
		posit.addWidget(self.fichier, 1, 1, 1, 2)
		posit.addWidget(self.fichierSelect, 1, 3, 1, 1)
		
		posit.addWidget(self.labellimit, 3, 0)
		posit.addWidget(self.limit, 3, 1, 1, 2)
		posit.addWidget(self.labellimit2, 3, 3, 1, 1)
		
		
		posit.addWidget(self.labelCheckupdate,5, 0)
		posit.addWidget(self.checkupdate,5 ,1)
		posit.addWidget(self.checkupdateDelay,5,2,1,2)
		
		posit.addWidget(self.save, 6, 2)
		posit.addWidget(self.cancel, 6, 3)
		self.setLayout(posit)

	#========================================================================
	def selectDir_m(self):
		dirPath = QFileDialog.getExistingDirectory(self, u"Dossier de téléchargement", self.userPersonalPath)
		if dirPath != "":
			if platform.system() == 'Windows':
				self.fichier.setText(dirPath.replace('/','\\'))
			else:
				self.fichier.setText(dirPath)

	#========================================================================
	def save_m(self):
		destination = self.fichier.text()
		if(self.checkupdate.checkState()==Qt.Checked):
			checkupdate = 1
		else:
			checkupdate = 0
		checkupdateDelay = self.checkupdateDelay.currentIndex()
		limit = int(self.limit.text())
		
		saveOptionsFile(self.parent.configDir, destination, checkupdate, checkupdateDelay, self.parent.checkupdateLast, limit, self.parent.verbose)
		
		self.parent.limit = limit
		
		for platform in self.parent.supportedPlatform:
			if platform in self.parent.telech:
				if self.parent.telech[platform]!=None and self.parent.telech[platform].isRunning():
					self.parent.telech[platform].httpreq.limit = limit
		
		
		self.parent.fichier.setText(u"%s" % destination)
		self.fichier.setText(u"%s" % destination)
		self.parent.defaultDir = destination
		
		self.close()

	#========================================================================
	def cancel_m(self):
		self.close()
		
def saveOptionsFile(configDir, destination, checkupdate, checkupdateDelay, checkupdateLast, limit, verbose):
	config = unicode(u"destination=%s\n" % destination)
	config+= unicode(u"checkupdate=%s\n" % checkupdate)
	config+= unicode(u"checkupdatedelay=%s\n" % checkupdateDelay)
	config+= unicode(u"checkupdatelast=%s\n" % checkupdateLast)
	config+= unicode(u"limit=%s\n" % limit)
	config+= unicode(u"verbose=%s\n" % limit)
	
	setupFilePath = os.path.join(configDir, "setup.ini")
	setupFile = open(setupFilePath, "w+")
	setupFile.write(config.encode('utf-8'))
	setupFile.close()
